<!doctype html>
<html lang="en" xmlns="http://www.w3.org/1999/xhtml">
<head>
<title></title>
</head>
<body>
<a href="{{ base_url }}/#/surveys/{{ instance.id }}">
  Head to the app
</a> to fill out the "{{ instance.survey.title }}" survey.
</body>
</html>
