# Generated by Django 4.2.6 on 2023-11-23 11:10

from django.db import migrations


class Migration(migrations.Migration):
    dependencies = [
        ("df_survey", "0004_alter_usersurvey_unique_together"),
    ]

    operations = [
        migrations.AlterUniqueTogether(
            name="response",
            unique_together={("usersurvey", "question")},
        ),
    ]
